@@ -4,8 +4,8 @@ from aerosandbox.performance import *
 
 class AeroProblem(AeroSandboxObject):
     def __init__(self,
-                 airplane,  # type: Airplane
-                 op_point,  # type: OperatingPoint
+                 airplane: Airplane,
+                 op_point: OperatingPoint,
                  ):
         self.airplane = airplane
         self.op_point = op_point
